package fi.jyu.intellij.comtest.common.util

import com.intellij.ide.SaveAndSyncHandler
import com.intellij.openapi.fileEditor.FileDocumentManager
import com.intellij.openapi.project.Project
import com.intellij.openapi.vfs.VirtualFileManager

/**
 * Refresh the project, apply an action and then synchronize all project files.
 *
 * @param T Return type of the action.
 * @param project Project to synchronize.
 * @param action action to apply
 * @return Return value of the action.
 */
fun <T> runWithRefresh(project: Project?, action: () -> T): T {
    project?.save()
    FileDocumentManager.getInstance().saveAllDocuments()
    val res = action()
    SaveAndSyncHandler.getInstance().refreshOpenFiles()
    VirtualFileManager.getInstance().refreshWithoutFileWatcher(false)
    return res
}